@@ -76,6 +76,8 @@ def parse(
             else:
                 data.append(datum)
                 continue
+            if log.empty:
+                raise pandas.errors.EmptyDataError
         except (IOError, pandas.errors.EmptyDataError):
             datum[key_epoch] = 0
             datum[key_iteration] = 0
